aboutsummaryrefslogtreecommitdiffstats
path: root/strlcat.c
diff options
context:
space:
mode:
authorsin <sin@2f30.org>2015-11-20 14:12:47 +0000
committersin <sin@2f30.org>2015-11-20 14:12:47 +0000
commitebaa637b0b30d7fa70fdd4ca61f8b1149e60e819 (patch)
tree71d2574cdba394d6a6896935568b99e460150fc4 /strlcat.c
parent9b47bfd9aa26c0dbc3ed63dd1960918359cf09b0 (diff)
downloadnoice-ebaa637b0b30d7fa70fdd4ca61f8b1149e60e819.tar.gz
Sync strlcpy/strlcat from OpenBSD
Diffstat (limited to 'strlcat.c')
-rw-r--r--strlcat.c49
1 files changed, 26 insertions, 23 deletions
diff --git a/strlcat.c b/strlcat.c
index 979c41b..bc523fb 100644
--- a/strlcat.c
+++ b/strlcat.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 1998 Todd C. Miller <Todd.Miller@courtesan.com>
+ * Copyright (c) 1998, 2015 Todd C. Miller <Todd.Miller@courtesan.com>
*
* Permission to use, copy, modify, and distribute this software for any
* purpose with or without fee is hereby granted, provided that the above
@@ -20,33 +20,36 @@
#include "util.h"
/*
* Appends src to string dst of size siz (unlike strncat, siz is the
* full size of dst, not space left). At most siz-1 characters
* will be copied. Always NUL terminates (unless siz <= strlen(dst)).
* Returns strlen(src) + MIN(siz, strlen(initial dst)).
* If retval >= siz, truncation occurred.
*/
size_t
-strlcat(char *dst, const char *src, size_t siz)
+strlcat(char *dst, const char *src, size_t dsize)
{
- char *d = dst;
- const char *s = src;
- size_t n = siz;
+ const char *odst = dst;
+ const char *osrc = src;
+ size_t n = dsize;
size_t dlen;
- /* Find the end of dst and adjust bytes left but don't go past end */
- while (n-- != 0 && *d != '\0')
- d++;
- dlen = d - dst;
- n = siz - dlen;
- if (n == 0)
- return(dlen + strlen(s));
- while (*s != '\0') {
- if (n != 1) {
- *d++ = *s;
+
+ /* Find the end of dst and adjust bytes left but don't go past end. */
+ while (n-- != 0 && *dst != '\0')
+ dst++;
+ dlen = dst - odst;
+ n = dsize - dlen;
+
+ if (n-- == 0)
+ return(dlen + strlen(src));
+ while (*src != '\0') {
+ if (n != 0) {
+ *dst++ = *src;
n--;
}
- s++;
+ src++;
}
- *d = '\0';
- return(dlen + (s - src)); /* count does not include NUL */
+ *dst = '\0';
+
+ return(dlen + (src - osrc)); /* count does not include NUL */
}
Un proyecto texto-plano.xyz
@@ -20,33 +20,36 @@
#include "util.h"
/*
- * Appends src to string dst of size siz (unlike strncat, siz is the
- * full size of dst, not space left). At most siz-1 characters
- * will be copied. Always NUL terminates (unless siz <= strlen(dst)).
- * Returns strlen(src) + MIN(siz, strlen(initial dst)).
- * If retval >= siz, truncation occurred.
+ * Appends src to string dst of size dsize (unlike strncat, dsize is the
+ * full size of dst, not space left). At most dsize-1 characters
+ * will be copied. Always NUL terminates (unless dsize <= strlen(dst)).
+ * Returns strlen(src) + MIN(dsize, strlen(initial dst)).
+ * If retval >= dsize, truncation occurred.
*/
size_t